@@ -16,5 +16,5 @@
 from horizon.test.settings import *  # noqa
 from openstack_dashboard.test.settings import *  # noqa
 
-INSTALLED_APPS = list(INSTALLED_APPS)
+INSTALLED_APPS = list(INSTALLED_APPS)  # noqa: F999
 INSTALLED_APPS.append('mistraldashboard')
